//[mahjong-utils](../../../../index.md)/[mahjongutils.hanhu](../../index.md)/[ChildPoint](../index.md)/[Companion](index.md)

# Companion

[common]\
object [Companion](index.md)

## Properties

| Name | Summary |
|---|---|
| [Baiman](-baiman.md) | [common]<br>val [Baiman](-baiman.md): [ChildPoint](../index.md) |
| [Haneman](-haneman.md) | [common]<br>val [Haneman](-haneman.md): [ChildPoint](../index.md) |
| [Mangan](-mangan.md) | [common]<br>val [Mangan](-mangan.md): [ChildPoint](../index.md) |
| [Sanbaiman](-sanbaiman.md) | [common]<br>val [Sanbaiman](-sanbaiman.md): [ChildPoint](../index.md) |
| [Yakuman](-yakuman.md) | [common]<br>val [Yakuman](-yakuman.md): [ChildPoint](../index.md) |
